@@ -23,13 +23,7 @@ if [[ $0 == ${BASH_SOURCE[0]} ]] ; then
     dirname=${BASH_SOURCE[0]%/*}
     [[ $dirname == $0 ]] && top_dir='../..' || top_dir=${dirname}/../..
     [[ -z $_Dbg_libdir ]] && _Dbg_libdir=$top_dir
-    for file in help alias ; do source $top_dir/lib/${file}.sh; done
-fi
-
-typeset -x _Dbg_pygments_styles=''
-
-if (( _Dbg_working_term_highlight )) ; then
-   _Dbg_pygments_styles=$("${_Dbg_libdir}/lib/term-highlight.py" -L)
+    for file in help alias ; do source "$top_dir/lib/${file}.sh"; done
 fi
 
 _Dbg_complete_style() {
