@@ -1,7 +1,8 @@
 # -*- shell-script -*-
 # debugger command options processing. The bane of programming.
 #
-#   Copyright (C) 2008-2012, 2014-2019 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008-2012, 2014-2019, 2021, 2023-2024
+#   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -94,9 +95,11 @@ if ( pygmentize --version || pygmentize -V ) 2>/dev/null 1>/dev/null ; then
 fi
 
 typeset -ix _Dbg_working_term_highlight
+typeset -x _Dbg_pygments_styles=''
 
 if "${_Dbg_libdir}/lib/term-highlight.py" -V 2>/dev/null  1>/dev/null ; then
     _Dbg_working_term_highlight=1
+    _Dbg_pygments_styles=$("${_Dbg_libdir}/lib/term-highlight.py" -L)
 else
     _Dbg_working_term_highlight=0
 fi
@@ -129,8 +132,10 @@ _Dbg_parse_options() {
 
     typeset -i _Dbg_o_quiet=0
     typeset -i _Dbg_o_version=0
+    typeset -i _Dbg_highlight_enabled=1
+    typeset OPTLARG OPTLERR OPTLPENDING opt
 
-    while getopts_long A:Bc:x:hL:nqTt:Yy:VX opt \
+    while getopts_long A:Bc:x:hL:nqS:T:t:Yy:VX opt \
         annotate     required_argument       \
         basename     no_argument             \
         command      required_argument       \
@@ -144,6 +149,7 @@ _Dbg_parse_options() {
         no-init      no_argument             \
         nx           no_argument             \
         quiet        no_argument             \
+        style        required_argument       \
         tempdir      required_argument       \
         tty          required_argument       \
         terminal     required_argument       \
@@ -175,16 +181,16 @@ _Dbg_parse_options() {
 		esac
 
 		if (( ! _Dbg_have_working_pygmentize )) ; then
-                    printf "Can't run pygmentize. --highlight forced off" >&2
+                    printf "Can't run pygmentize. --highlight forced off." >&2
+		    _Dbg_highlight_enabled=0
 		    _Dbg_set_highlight=''
                 fi
                 ;;
             no-highlight )
+                _Dbg_highlight_enabled=0
                 _Dbg_set_highlight=''   ;;
             init-file )
-                set -x
                 _Dbg_o_init_files+="$OPTLARG"
-                set +x
                 ;;
             L | library )               ;;
             V | version )
@@ -193,6 +199,15 @@ _Dbg_parse_options() {
                 _Dbg_o_nx=1             ;;
             q | quiet )
                 _Dbg_o_quiet=1          ;;
+            S | style )
+		if (( ! _Dbg_have_working_pygmentize )) ; then
+                    printf "Can't run pygmentize. --style option ignored." >&2
+		elif [[ "${_Dbg_pygments_styles#*$OPTLARG}" != "$_Dbg_pygments_styles" ]] ; then
+		    _Dbg_set_style="$OPTLARG"
+		else
+		    printf "Can't find style ${OPTLARG}; --style option ignored." >&1
+		fi
+                ;;
             tempdir)
                 _Dbg_tmpdir=$OPTLARG    ;;
             terminal | tty )
@@ -226,7 +241,7 @@ _Dbg_parse_options() {
         [[ -n $_Dbg_release ]] ; then
         echo "$_Dbg_shell_name debugger, $_Dbg_debugger_name, release $_Dbg_release"
         printf '
-Copyright 2002-2004, 2006-2012, 2014, 2016-2019 Rocky Bernstein
+Copyright 2002-2004, 2006-2012, 2014, 2016-2019, 2021, 2023-2024 Rocky Bernstein
 This is free software, covered by the GNU General Public License, and you are
 welcome to change it and/or distribute copies of it under certain conditions.
 
@@ -249,26 +264,25 @@ welcome to change it and/or distribute copies of it under certain conditions.
     fi
     unset _Dbg_o_annotate _Dbg_o_version _Dbg_o_quiet
     _Dbg_script_args=("$@")
+
+    if (( _Dbg_have_working_pygmentize )) && (( _Dbg_highlight_enabled )) && [[ -z "$_Dbg_set_highlight" ]] ; then
+        # Honor DARK_BG if already set. If not set, set it.
+        if [[ -z "$DARK_BG" ]] ; then
+        . "${_Dbg_libdir}/init/term-background.sh" >/dev/null
+        fi
+
+        # DARK_BG is now either 0 or 1.
+        # Set _Dbg_set_highlight based on DARK_BG
+        # Note however that options processing has one more chance to
+        # change _Dbg_set_highlight
+        if (( $DARK_BG )); then
+        _Dbg_set_highlight="dark"
+        else
+        _Dbg_set_highlight="light"
+        fi
+    fi
 }
 
-if (( _Dbg_have_working_pygmentize )) && [[ -z "$_Dbg_set_highlight" ]] ; then
-    # Honor DARK_BG if already set. If not set, set it.
-    if [[ -z "$DARK_BG" ]] ; then
-	. "${_Dbg_libdir}/init/term-background.sh" >/dev/null
-    fi
-
-    # DARK_BG is now either 0 or 1.
-    # Set _Dbg_set_highlight based on DARK_BG
-    # Note however that options processing has one more chance to
-    # change _Dbg_set_highlight
-    if (( $DARK_BG )); then
-	_Dbg_set_highlight="dark"
-    else
-	_Dbg_set_highlight="light"
-    fi
-fi
-
-
 # Stand-alone Testing.
 if [[ -n "$_Dbg_dbg_opts_test" ]] ; then
     OPTLIND=1
