@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # fns.sh - Debugger Utility Functions
 #
-#   Copyright (C) 2002-2011 2019
+#   Copyright (C) 2002-2011 2019 2021
 #   Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
@@ -22,15 +22,15 @@
 typeset -a _Dbg_yn; _Dbg_yn=("n" "y")
 
 # Return $2 copies of $1. If successful, $? is 0 and the return value
-# is in result.  Otherwise $? is 1 and result ''
+# is in _Dbg_result.  Otherwise $? is 1 and _Dbg_result ''
 function _Dbg_copies {
-    result=''
+    _Dbg_result=''
     (( $# < 2 )) && return 1
     typeset -r string="$1"
     typeset -i count=$2 || return 2
     (( count > 0 )) || return 3
-    builtin printf -v result "%${count}s" ' ' || return 3
-    result=${result// /$string}
+    builtin printf -v _Dbg_result "%${count}s" ' ' || return 3
+    _Dbg_result=${_Dbg_result// /$string}
     return 0
 }
 
@@ -58,11 +58,11 @@ function _Dbg_esc_dq {
 # gives syntax errors when this is put in place.
 typeset -a _Dbg_eval_re;
 _Dbg_eval_re=(
-    '^[ \t]*(if|elif)[ \t]+([^;]*)((;[ \t]*then?)?|$)'
-    '^[ \t]*return[ \t]+(.*)$'
-    '^[ \t]*while[ \t]+([^;]*)((;[ \t]*do?)?|$)'
-    '^[ \t]*[A-Za-z_][A-Za-z_0-9_]*[+-]?=(.*$)'
-    "^[ \t]*[A-Za-z_][A-Za-z_0-9_]*\[[0-9]+\][+-]?=(.*\$)"
+    '^[[:blank:]]*(if|elif)[[:blank:]]+([^;]*)((;[[:blank:]]*then?)?|$)'
+    '^[[:blank:]]*return[[:blank:]]+(.*)$'
+    '^[[:blank:]]*while[[:blank:]]+([^;]*)((;[[:blank:]]*do?)?|$)'
+    '^[[:blank:]]*[A-Za-z_][A-Za-z_0-9_]*[+-]?=(.*$)'
+    "^[[:blank:]]*[A-Za-z_][A-Za-z_0-9_]*\[[0-9]+\][+-]?=(.*\$)"
 )
 
 # Removes "[el]if" .. "; then" or "while" .. "; do" or "return .."
@@ -197,6 +197,9 @@ function _Dbg_linespec_setup {
   typeset -ri is_function=${word[1]}
   line_number=${word[0]}
   full_filename=$(_Dbg_is_file "$filename")
+  if [[ -z "$full_filename" ]] ; then
+      full_filename="$(_Dbg_resolve_expand_filename "$filename")"
+  fi
 
   if (( is_function )) ; then
       if [[ -z "$full_filename" ]] ; then
@@ -214,16 +217,16 @@ function _Dbg_linespec_setup {
 # We return the filename last since that can have embedded blanks.
 function _Dbg_parse_linespec {
   typeset linespec=$1
-  eval "$_seteglob"
+  eval "$_Dbg_seteglob"
   case "$linespec" in
 
     # line number only - use _Dbg_frame_last_filename for filename
-    $int_pat )
+    $_Dbg_int_pat )
       echo "$linespec 0 \"$_Dbg_frame_last_filename\""
       ;;
 
     # file:line
-    [^:][^:]*[:]$int_pat )
+    [^:][^:]*[:]$_Dbg_int_pat )
       # Split the POSIX way
       typeset line_word=${linespec##*:}
       typeset file_word=${linespec%${line_word}}
