@@ -94,13 +94,13 @@ test_action()
     assertEquals '1' "${#msgs[@]}"
 }
 
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
 
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
-# Make sure /src/external-vcs/sourceforge/bashdb has a trailing slash
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
+# Make sure /src/external-vcs/github/Trepan-Debuggers/bashdb has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
 . ${abs_top_srcdir}init/pre.sh
