@@ -17,21 +17,21 @@ test_preserve_set_opts()
 	# Name we refer to ourselves by
 	typeset _Dbg_debugger_name='bashdb'
 	# The release name we are configured to run under.
-	typeset _Dbg_release='5.0-1.1.2'
+	typeset _Dbg_release='5.2-1.2.0'
 	. ${top_builddir}/bashdb-trace -L $libdir
 	assertEquals $old_opts $-
     else
 	echo 'Skipping test - building outside of source complications'
     fi
 
-    (. ${top_builddir}/bashdb-trace -L $libdir/init/opts.sh)
+    (. ${top_builddir}/bashdb-trace -L $libdir/init/opts.sh) 2> /dev/null
     assertEquals $? 1
     set +u
 }
 
 prefix=/usr
-top_builddir=/src/external-vcs/sourceforge/bashdb
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+top_builddir=/src/external-vcs/github/Trepan-Debuggers/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
