@@ -63,12 +63,12 @@ test_check_line()
     _Dbg_check_line 10000 $shunit_file
 }
 
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
 
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
