@@ -163,11 +163,11 @@ test_frame_print()
     assertEquals "->0 in file \`dbg-cmds.sh' at line 2" "$msg"
 }
 
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong: abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
