@@ -2,7 +2,7 @@
 # -*- shell-script -*-
 this_script=test-get-sourceline.sh
 
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 
@@ -61,7 +61,7 @@ test_get_source_line_with_spaces()
     fi
 }
 
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
