@@ -23,12 +23,12 @@ test_pre_do_show_version()
     # Name we refer to ourselves by
     typeset _Dbg_debugger_name='bashdb'
     # The release name we are configured to run under.
-    typeset _Dbg_release='5.0-1.1.2'
+    typeset _Dbg_release='5.2-1.2.0'
 
     version_string=$(_Dbg_do_show_version 2>&1)
-    assertEquals "bashdb, release 5.0-1.1.2" "$version_string"
+    assertEquals "bashdb, release 5.2-1.2.0" "$version_string"
 }
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
