@@ -17,7 +17,7 @@ test_require()
     assertEquals $requires_size ${#_Dbg_requires[@]}
 }
 
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
