@@ -16,7 +16,7 @@ test_run_not_running()
     assertEquals  1 ${#errs[@]}
 }
 
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
