@@ -45,12 +45,24 @@ test_sort()
     assertNotEquals "0" "$?"
 }
 
+test_sort_named() {
+    local LC_ALL=C # for predictable sort order
+    typeset -a my_expected=(1 2 3 A B X b y z)
 
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+    typeset -a my_data=(z b y 2 3 1 X A B)
+    sort_list_named my_data 0 ${#my_data[@]}-1
+    assertEquals "sort_list_named must complete successfully" 0 $?
+
+    for ((i=0; i < ${#my_expected[@]}; i++)); do
+        assertEquals "Expected sorted data at index $i." "${my_expected[i]}" "${my_data[i]}"
+    done
+}
+
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
