@@ -56,12 +56,12 @@ test_validate_is_integer()
 
 }
 
-# Make sure /src/external-vcs/sourceforge/bashdb has a trailing slash
-if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
+# Make sure /src/external-vcs/github/Trepan-Debuggers/bashdb has a trailing slash
+if [ '/src/external-vcs/github/Trepan-Debuggers/bashdb' = '' ] ; then
   echo "Something is wrong: abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+abs_top_srcdir=/src/external-vcs/github/Trepan-Debuggers/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 . ${abs_top_srcdir}test/unit/helper.sh
